@@ -29,9 +29,9 @@
 #' @examples
 #' \dontrun{
 #'  l <- ala_fields("layers")
-#'  l[,4]
+#'  l[, 4]
 #'  o <- ala_fields("occurrence")
-#'  o[1:13,]
+#'  o[1:13, ]
 #'  a <- ala_fields("assertions")
 #'  a$description
 #'  field_info("cl22")
@@ -42,68 +42,68 @@
 # TODO: Summary of #fields returned
 # ids from http://spatial.ala.org.au/ws/layers are NUMERIC but lookup prepends "el" and "cl"! 
 
-ala_fields <- function(fields_type="occurrence",as_is=TRUE) {
+ala_fields <- function(fields_type="occurrence", as_is=TRUE) {
     assert_that(is.string(fields_type))
-    assert_that(is.flag(as_is))
-    fields_type <- match.arg(tolower(fields_type),c("occurrence","occurrence_stored","occurrence_indexed","general","layers","assertions"))
+    assert_that(is.flag(as_is), !is.na(as_is))
+    fields_type <- match.arg(tolower(fields_type), c("occurrence", "occurrence_stored", "occurrence_indexed", "general", "layers", "assertions"))
     this_url <- switch(fields_type,
            "general"={
-               build_url_from_parts(getOption("ALA4R_server_config")$base_url_bie,c("admin","indexFields"))
+               build_url_from_parts(getOption("ALA4R_server_config")$base_url_bie, c("admin", "indexFields"))
            },
            "occurrence_indexed"=,
            "occurrence_stored"=,
            "occurrence"={
-               build_url_from_parts(getOption("ALA4R_server_config")$base_url_biocache,c("index","fields"))
+               build_url_from_parts(getOption("ALA4R_server_config")$base_url_biocache, c("index", "fields"))
            },
            "layers"={
-               build_url_from_parts(getOption("ALA4R_server_config")$base_url_spatial,"fields")
+               build_url_from_parts(getOption("ALA4R_server_config")$base_url_spatial, "fields")
            },
            "assertions"={
-               build_url_from_parts(getOption("ALA4R_server_config")$base_url_biocache,c("assertions","codes"))
+               build_url_from_parts(getOption("ALA4R_server_config")$base_url_biocache, c("assertions", "codes"))
            }
            )
     
-    x <- cached_get(this_url,type="json")
+    x <- cached_get(this_url, type="json")
     ## we have a list of unwanted columns that get removed from results
     ## since this function returns a list of field names, also remove the unwanted fields from the results list
-    x <- x[!x$name %in% unwanted_columns(fields_type),]
+    x <- x[!x$name %in% unwanted_columns(fields_type), ]
     
     ## for "layers", shorter, more manageable names are provided from http://spatial.ala.org.au/ws/layers in API. Add these as an extra column: shortName
-    if (identical(fields_type,"layers")) {
-        more_x <- cached_get(url=build_url_from_parts(getOption("ALA4R_server_config")$base_url_spatial,"layers"),type="json")
+    if (identical(fields_type, "layers")) {
+        more_x <- cached_get(url=build_url_from_parts(getOption("ALA4R_server_config")$base_url_spatial, "layers"), type="json")
         ## just pull out the bits that we want and construct ids here that match the field names in x
-        more_x$id <- paste(substr(tolower(more_x$type),1,1),"l",more_x$id,sep="")
-        more_x <- more_x[,c("name","id")]
-        names(more_x) <- c("shortName","id")
-        x <- merge(x,more_x,by="id")
+        more_x$id <- paste(substr(tolower(more_x$type), 1, 1), "l", more_x$id, sep="")
+        more_x <- more_x[, c("name", "id")]
+        names(more_x) <- c("shortName", "id")
+        x <- merge(x, more_x, by="id")
         x$type[x$type=="c"] <- "Contextual"
         x$type[x$type=="b"] <- "Contextual" ## there is an errant "b" here that should be "c"
         x$type[x$type=="e"] <- "Environmental" ## for consistency with search_layers
-    } else if (identical(fields_type,"occurrence_stored")) {
-        x <- x[x$stored,]
-    } else if (identical(fields_type,"occurrence_indexed")) {
-        x <- x[x$indexed,]
+    } else if (identical(fields_type, "occurrence_stored")) {
+        x <- x[x$stored, ]
+    } else if (identical(fields_type, "occurrence_indexed")) {
+        x <- x[x$indexed, ]
     }
     if (!as_is) {
-        ## old code ## names(x) <- rename_variables(names(x),type=fields_type)
+        ## old code ## names(x) <- rename_variables(names(x), type=fields_type)
         ## Nooooo! this should have been applied to x$name not names(x)
         ## as_is now defaults to TRUE (v1.20) to keep default behaviour the same as with previous versions
-        if (! fields_type %in% c("layers")) {
-            ## don't apply when fields_type is layers, because we want name left as full name 
-            x$name <- rename_variables(x$name,type=fields_type)
+        if (!(fields_type %in% c("layers"))) {
+            ## don't apply when fields_type is layers,  because we want name left as full name 
+            x$name <- rename_variables(x$name, type=fields_type)
         }
     }
     ## some other hard-coded name changes
     names(x)[tolower(names(x))=="desc"] <- "description"
     ## drop unwanted columns
-    xcols <- setdiff(names(x),unwanted_columns(fields_type))
-    x[,xcols]
+    xcols <- setdiff(names(x), unwanted_columns(fields_type))
+    x[, xcols]
 }
 
 
 #' @rdname ala_fields
 #' @export
-field_info  <-  function(field_id,maxrows=50,record_count_only=FALSE) {
+field_info  <-  function(field_id, maxrows=50, record_count_only=FALSE) {
     assert_that(is.notempty.string(field_id))
     assert_that(is.count(maxrows) || maxrows==-1)
     assert_that(is.flag(record_count_only))
@@ -111,26 +111,26 @@ field_info  <-  function(field_id,maxrows=50,record_count_only=FALSE) {
         ## override maxrows setting
         maxrows <- 0
     }
-    field_id <- fields_name_to_id(fields=field_id,fields_type="layers")
+    field_id <- fields_name_to_id(fields=field_id, fields_type="layers")
 
-    this_url <- build_url_from_parts(getOption("ALA4R_server_config")$base_url_spatial,c("field",field_id),query=list(pageSize=maxrows))
-    out  <-  cached_get(url=this_url,type="json") ## retrieve a max of 50 objects by default
+    this_url <- build_url_from_parts(getOption("ALA4R_server_config")$base_url_spatial, c("field", field_id), query=list(pageSize=maxrows))
+    out  <-  cached_get(url=this_url, type="json") ## retrieve a max of 50 objects by default
     if (is.null(out)) {
         ## un-matched field name, return an empty data frame
         if (ala_config()$warn_on_empty) {
-            warning("No information returned. Please check field_id is valid using ",getOption("ALA4R_server_config")$fields_function,"(\"layers\").")
+            warning("No information returned. Please check field_id is valid using ", getOption("ALA4R_server_config")$fields_function, "(\"layers\").")
         }
         data.frame()
     } else {
-        if (substr(field_id,1,2) == 'cl') {
+        if (substr(field_id, 1, 2) == 'cl') {
             if (record_count_only) {
                 return(out$number_of_objects)
             } else if (nrow(out$objects)<out$number_of_objects) {
                 ## we retrieved a subset of the full record set for this field, so let the user know
-                warning("field_info retrieved ",nrow(out$objects)," rows out of a total of ",out$number_of_objects," for this field. You may wish to increase the maxrows parameter, but be aware that a very large number of rows may crash R")
+                warning("field_info retrieved ", nrow(out$objects), " rows out of a total of ", out$number_of_objects, " for this field. You may wish to increase the maxrows parameter, but be aware that a very large number of rows may crash R")
             }
             out  <-  out$objects #keep only the content
-        } else if (substr(field_id,1,2) == 'el') {
+        } else if (substr(field_id, 1, 2) == 'el') {
             if (record_count_only) {
                 ## user has asked for number of rows, which is always 1 for el layers
                 return(1)
@@ -138,7 +138,7 @@ field_info  <-  function(field_id,maxrows=50,record_count_only=FALSE) {
             out  <-  as.data.frame(rbind(out)) #bind the data as a dataframe	
             rownames(out)  <-  NULL #reset the row names
         }
-        names(out) <- rename_variables(names(out),type="layers")
+        names(out) <- rename_variables(names(out), type="layers")
         out
     }
 }	
@@ -147,11 +147,11 @@ field_info  <-  function(field_id,maxrows=50,record_count_only=FALSE) {
 
 ## private function to replace any full field names (descriptions) with their id values
 ## e.g. "Radiation - lowest period (Bio22)" to id "el871"
-fields_name_to_id <- function(fields,fields_type,make_names=FALSE) {
+fields_name_to_id <- function(fields, fields_type, make_names=FALSE) {
     assert_that(is.character(fields))
     assert_that(is.string(fields_type))
     assert_that(is.flag(make_names)) ## if TRUE, apply make.names to variable names before matching
-    fields_type <- match.arg(tolower(fields_type),c("occurrence","general","layers","assertions"))
+    fields_type <- match.arg(tolower(fields_type), c("occurrence", "general", "layers", "assertions"))
     valid_fields <- ala_fields(fields_type=fields_type)
     ## merge differently for "layers" fields, because those column names differ from other fields_type
     ## for layers, the long name is in "desc", with the id in "id" (and "name" is something different)
@@ -167,32 +167,32 @@ fields_name_to_id <- function(fields,fields_type,make_names=FALSE) {
            )
     }
     switch(fields_type,
-           "layers"=laply(fields,function(z) ifelse(z %in% valid_fields$description & ! z %in% valid_fields$id,{
-               if (sum(valid_fields$description==z,na.rm=TRUE)>1) {
+           "layers"=laply(fields, function(z) ifelse(z %in% valid_fields$description & (!z %in% valid_fields$id), {
+               if (sum(valid_fields$description==z, na.rm=TRUE)>1) {
                    if (nchar(z)>0) { ## don't warn if field name is degenerate ""
-                       warning(" multiple ",fields_type," fields match the name \"",z,"\", using first")
+                       warning(" multiple ", fields_type, " fields match the name \"", z, "\", using first")
                    }
                }
                valid_fields$id[which(valid_fields$description==z)[1]]
-           },z)),
+           }, z)),
            "occurrence"=,
-           "assertions"=laply(fields,function(z) ifelse(z %in% valid_fields$description & ! z %in% valid_fields$name,{
-               if (sum(valid_fields$description==z,na.rm=TRUE)>1) {
+           "assertions"=laply(fields, function(z) ifelse(z %in% valid_fields$description & (!z %in% valid_fields$name), {
+               if (sum(valid_fields$description==z, na.rm=TRUE)>1) {
                    if (nchar(z)>0) {
-                       warning(" multiple ",fields_type," fields match the name \"",z,"\", using first")
+                       warning(" multiple ", fields_type, " fields match the name \"", z, "\", using first")
                    }
                }
                valid_fields$name[which(valid_fields$description==z)[1]]
-           },z)),
+           }, z)),
            fields ## default to just returning the fields as supplied 
        )
 }
 
 ## private function to replace any id values with their full field names (descriptions)
-fields_id_to_name <- function(fields,fields_type) {
+fields_id_to_name <- function(fields, fields_type) {
     assert_that(is.character(fields))
     assert_that(is.string(fields_type))
-    fields_type <- match.arg(tolower(fields_type),c("occurrence","general","layers","assertions"))
+    fields_type <- match.arg(tolower(fields_type), c("occurrence", "general", "layers", "assertions"))
     valid_fields <- ala_fields(fields_type=fields_type)
     ## merge differently for "layers" fields, because those column names differ from other fields_type
     ## for layers, the long name is in "desc", with the id in "id" (and "name" is something different)
@@ -201,23 +201,23 @@ fields_id_to_name <- function(fields,fields_type) {
     ## for general, there is no long name (description)
     ## for each one, warn if multiple matches on long name are found
     switch(fields_type,
-           "layers"=laply(fields,function(z) ifelse(z %in% valid_fields$id & ! z %in% valid_fields$description,{
-               if (sum(valid_fields$id==z,na.rm=TRUE)>1) {
+           "layers"=laply(fields, function(z) ifelse(z %in% valid_fields$id & (!z %in% valid_fields$description), {
+               if (sum(valid_fields$id==z, na.rm=TRUE)>1) {
                    if (nchar(z)>0) {
-                       warning(" multiple ",fields_type," fields match the id \"",z,"\", using first")
+                       warning(" multiple ", fields_type, " fields match the id \"", z, "\", using first")
                    }
                }
                valid_fields$description[which(valid_fields$id==z)[1]]
-           },z)),
+           }, z)),
            "occurrence"=,
-           "assertions"=laply(fields,function(z) ifelse(z %in% valid_fields$name & ! z %in% valid_fields$description,{
-               if (sum(valid_fields$name==z,na.rm=TRUE)>1) {
+           "assertions"=laply(fields, function(z) ifelse(z %in% valid_fields$name & (!z %in% valid_fields$description), {
+               if (sum(valid_fields$name==z, na.rm=TRUE)>1) {
                    if (nchar(z)>0) {
-                       warning(" multiple ",fields_type," fields match the id \"",z,"\", using first")
+                       warning(" multiple ", fields_type, " fields match the id \"", z, "\", using first")
                    }
                }
                valid_fields$description[which(valid_fields$name==z)[1]]
-           },z)),
+           }, z)),
            fields ## default to just returning the fields as supplied 
        )
 }
