@@ -1,24 +1,34 @@
 #' Get list of taxa and their occurrence counts
 #'
-#' Retrieve a list of taxa matching a search query, within a spatial search area, or both
+#' Retrieve a list of taxa matching a search query, within a spatial search area, or both.
+#'
+#' NOTE March 2017: the response object might include records with missing taxonomic information. This is an issue with the ALA server-side systems; see https://github.com/AtlasOfLivingAustralia/bie-index/issues/134
 #' 
-#' @references Associated ALA web service: \url{http://api.ala.org.au/#ws98}
+#' @references Associated ALA web service: \url{http://api.ala.org.au/#ws106}
 #' @references \url{http://www.geoapi.org/3.0/javadoc/org/opengis/referencing/doc-files/WKT.html}
 #' 
-#' @param taxon string: Text of taxon, e.g. "Macropus rufus" or "macropodidae"
+#' @param taxon string: (optional) query of the form field:value (e.g. "genus:Heleioporus") or a free text search (e.g. "macropodidae").
+#' For reliable results it is recommended to use a specific field where possible (see \code{ala_fields("occurrence_indexed")}
+#' for valid fields). It is also good practice to quote the taxon name if it contains multiple words, for example
+#' \code{taxon="taxon_name:\"Alaba vibex\""} (noting, however, that multi-word names are unlikely in the context of a specieslist
+#' search, where one would typically be searching for all species within, say, a genus or family)
 #' @param wkt string: WKT (well-known text) defining a polygon within which to limit taxon search, e.g. "POLYGON((140 -37,151 -37,151 -26,140 -26,140 -37))"
 #' @param fq string: character string or vector of strings, specifying filters to be applied to the original query. These are of the form "INDEXEDFIELD:VALUE" e.g. "kingdom:Fungi". See \code{ala_fields("occurrence_indexed",as_is=TRUE)} for all the fields that are queryable. NOTE that fq matches are case-sensitive, but sometimes the entries in the fields are not consistent in terms of case (e.g. kingdom names "Fungi" and "Plantae" but "ANIMALIA"). fq matches are ANDed by default (e.g. c("field1:abc","field2:def") will match records that have field1 value "abc" and field2 value "def"). To obtain OR behaviour, use the form c("field1:abc OR field2:def")
 #' @return data frame of results, where each row is a taxon, its classification information, and its occurrence count
 #' @seealso \code{\link{ala_fields}} for occurrence fields that are queryable via the \code{fq} parameter
 #' @examples
 #' \dontrun{
-#' x <- specieslist(taxon="macropus",wkt="POLYGON((145 -37,150 -37,150 -30,145 -30,145 -37))")
+#' x <- specieslist(taxon="genus:Hakea",wkt="POLYGON((145 -37,150 -37,150 -30,145 -30,145 -37))")
 #' 
 #' x <- specieslist(wkt="POLYGON((147.62 -42.83,147.60 -42.86,147.65 -42.87,147.70 -42.86,
 #'   147.62 -42.83))",fq="rank:species")
 #'
-#' x <- specieslist(wkt="POLYGON((145 -37,150 -37,150 -30,145 -30,145 -37))",fq="genus:Macropus")
-#' 
+#' x <- specieslist(wkt="POLYGON((145 -37,150 -37,150 -30,145 -30,145 -37))",fq="genus:Heleioporus")
+#'
+#' x <- specieslist(wkt="POLYGON((152.38 -30.43,152.5 -30.43,152.5 -30.5,152.38 -30.5,152.38 -30.43))",
+#'     fq="kingdom:Plantae")
+#' ## NOTE that this response might include records with empty or NA kingdom, phylum, or
+#' ##  class values, as per the note above.
 #' }
 #' @export specieslist
 
@@ -36,10 +46,6 @@ specieslist <- function(taxon,wkt,fq) {
         ## the server will provide this diagnostic info anyway
         this_query$wkt <- wkt
     }    
-    if (length(this_query)==0) {
-        ## not a valid request!
-        stop("invalid request: need either fq or wkt parameter to be specified")
-    }
     if (!missing(fq)) {
         assert_that(is.character(fq))
         ## can have multiple fq parameters, need to specify in url as fq=a:b&fq=c:d&fq=...
@@ -48,6 +54,14 @@ specieslist <- function(taxon,wkt,fq) {
         names(fq) <- rep("fq",length(fq))
         this_query <- c(this_query,fq)
     }
+    if (length(this_query)==0) {
+        ## not a valid request!
+        stop("invalid request: need to supply at least one of taxon, wkt, or fq parameter")
+    }
+    ## update March 2017: the service will actually accept a request with no parameters, so it's not strictly invalid.
+    ## But it's probably not a good idea to allow it, since it will be an enormous request.
+    ## If a user really needs to do it they can specify taxon="*"
+    
     this_query$facets <- "taxon_concept_lsid" ## or "species_guid" to avoid genus and higher records
     this_query$lookup <- "true" ## "set to true if you would like the download include the scientific names and higher classification for the supplied guids. Downloads that include this param will take extra time as a lookup need to be performed"
     this_query$count <- "true"
