@@ -2,7 +2,7 @@
 #' 
 #' @references Associated ALA web service: \url{http://api.ala.org.au/#ws2}
 #' 
-#' @param query string: (optional) query of the form field:value (e.g. "genus:Macropus") or a free text search ("Alaba vibex")
+#' @param query string: (optional) query of the form field:value (e.g. "genus:Heleioporus") or a free text search ("Alaba vibex")
 #' @param fq string: character string or vector of strings, specifying filters to be applied to the original query. 
 #' These are of the form "INDEXEDFIELD:VALUE" e.g. "kingdom:Fungi". See \code{ala_fields("general",as_is=TRUE)} for all the 
 #' fields that are queryable. NOTE that fq matches are case-sensitive, but sometimes the entries in the fields are 
@@ -21,7 +21,7 @@
 #' @examples
 #' \dontrun{
 #' ## simplest usage
-#' x <- taxinfo_download("rk_genus:Macropus")
+#' x <- taxinfo_download("rk_genus:Heleioporus")
 #' 
 #' ## Data for Fabaceae with specified fields
 #' x <- taxinfo_download("rk_family:Fabaceae",fields=c("guid","parentGuid","rk_kingdom","rk_phylum",
@@ -79,7 +79,7 @@ taxinfo_download <- function(query,fq,fields,verbose=ala_config()$verbose,use_da
         read_ok <- FALSE
         if (use_data_table & requireNamespace("data.table",quietly=TRUE)) { ## if data.table package is available
             tryCatch({
-                x <- data.table::fread(thisfile,data.table=FALSE,stringsAsFactors=FALSE,header=TRUE,verbose=verbose)
+                x <- data.table::fread(thisfile, data.table=FALSE, stringsAsFactors=FALSE, header=TRUE, verbose=verbose, na.strings="NA", logical01=FALSE)
                 names(x) <- make.names(names(x))
                 if (!empty(x)) {
                     ## convert column data types
